package com.caimei365.manager.service.hehe.product.impl;


import com.caimei.utils.AppUtils;
import com.caimei.utils.MathUtil;
import com.caimei365.manager.config.thinkgem.Global;
import com.caimei365.manager.dao.hehe.HeHeProductDao;
import com.caimei365.manager.entity.PaginationVo;
import com.caimei365.manager.entity.ResponseJson;
import com.caimei365.manager.entity.hehe.product.*;
import com.caimei365.manager.service.hehe.product.HeHeProductService;
import com.github.pagehelper.PageHelper;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

@Service
@Slf4j
public class HeHeProductServiceImpl implements HeHeProductService {

    @Resource
    private HeHeProductDao productDao;

    @Override
    public ResponseJson<PaginationVo<HeHeProduct>> productList(HeHeProduct product, int pageNum, int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<HeHeProduct> list = productDao.findProductList(product);
        String wwwServer = Global.getConfig("wwwServer");
        list.forEach(p -> {
            HeHeProduct cp = productDao.findProductElement(p.getProductId());
            p.setCostPrice(cp.getCostPrice());
            p.setShopPercent(cp.getShopPercent());
            p.setCostType(cp.getCostType());
            p.setPrice(cp.getPrice());
            //比例成本
            if ("2".equals(p.getCostType())) {
                BigDecimal costPrice = MathUtil.div(MathUtil.mul(p.getPrice(), p.getShopPercent()), 100, 2);
                p.setCostPrice(costPrice);
            }
            p.setMainImage(AppUtils.getImageURL("product", p.getMainImage(), 0, wwwServer));
        });
        PaginationVo<HeHeProduct> page = new PaginationVo<>(list);
        return ResponseJson.success(page);
    }

    @Override
    public ResponseJson<PaginationVo<HeHeBigType>> bigTypeList(HeHeBigType type, int pageNum, int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<HeHeBigType> list = productDao.findBigTypeList(type);
        PaginationVo<HeHeBigType> page = new PaginationVo<>(list);
        return ResponseJson.success(page);
    }

    @Override
    public ResponseJson<PaginationVo<HeHeActivity>> activeList(HeHeActivity activity, int pageNum, int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<HeHeActivity> list = productDao.findActivityList(activity);
        PaginationVo<HeHeActivity> page = new PaginationVo<>(list);
        return ResponseJson.success(page);
    }

    @Override
    public ResponseJson<PaginationVo<DiscountActivity>> discountActiveList(DiscountActivity activity, int pageNum, int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<DiscountActivity> list = productDao.findDiscountActivityList(activity);
        list.forEach(this::setActivityStatus);
        PaginationVo<DiscountActivity> page = new PaginationVo<>(list);
        return ResponseJson.success(page);
    }

    @Override
    public ResponseJson<PaginationVo<ShareReduction>> shareReductionList(ShareReduction reduction, int pageNum, int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<ShareReduction> list = productDao.findShareReductionList(reduction);
        list.forEach(this::setShareReductionStatus);
        PaginationVo<ShareReduction> page = new PaginationVo<>(list);
        return ResponseJson.success(page);
    }

    @Override
    public ResponseJson<PaginationVo<InsideDiscount>> insideDiscountList(InsideDiscount discount, int pageNum, int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<InsideDiscount> list = productDao.findInsideDiscountList(discount);
        PaginationVo<InsideDiscount> page = new PaginationVo<>(list);
        return ResponseJson.success(page);
    }

    public void setShareReductionStatus(ShareReduction reduction) {
        Date date = new Date();
        if (reduction != null) {
            if (date.compareTo(reduction.getStartTime()) < 0) {
                reduction.setStatus(1);
            } else if (date.compareTo(reduction.getEndTime()) > 0) {
                reduction.setStatus(3);
            } else {
                reduction.setStatus(2);
            }
        }
    }

    public void setActivityStatus(DiscountActivity activity) {
        Date date = new Date();
        if (activity != null) {
            if (date.compareTo(activity.getOnlineTime()) < 0) {
                activity.setStatus(1);
            } else if (date.compareTo(activity.getOfflineTime()) > 0) {
                activity.setStatus(3);
            } else {
                activity.setStatus(2);
            }
        }
    }
}
